# twgw

Under construction! Not ready for use yet! Currently experimenting and planning!

Developed by Iyappan from Trackerwave (c) 2022

## Examples of How To Use (Buggy Alpha Version)

-get
-post
-put
